@@ -4,15 +4,18 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef OPENEMAILADDRESSJOB_H
-#define OPENEMAILADDRESSJOB_H
+#pragma once
 
 #include "akonadi-contact_export.h"
 
 #include <KJob>
 
+#include <memory>
+
 namespace Akonadi
 {
+class OpenEmailAddressJobPrivate;
+
 /**
  * @short A job to open the contact editor for a contact with a given email address.
  *
@@ -46,10 +49,9 @@ public:
 
 private:
     //@cond PRIVATE
-    class Private;
-    Private *const d;
+    friend class OpenEmailAddressJobPrivate;
+    std::unique_ptr<OpenEmailAddressJobPrivate> const d;
     //@endcond
 };
 }
 
-#endif
